@@ -36,6 +36,10 @@ fn simple() {
             title: "Assistance".to_string(),
             description: "Another word for help.".to_string(),
         }, // TestStruct
+        TestStruct {
+            title: "Surfin' Bird".to_string(),
+            description: "The Bird's the Word".to_string(),
+        }, // TestStruct
     ]; // vec!
 
     test_vec
@@ -50,6 +54,11 @@ fn simple() {
 
     // Test `keyword_autocomplete` method:
 
+    println!("Autocomplete keyword: {:#?}", search_index.keyword_autocomplete(&"The B".to_string()));
+    assert_eq!(search_index.keyword_autocomplete(&"Th".to_string()), vec!["the", "the bird's the word"]);
+
+    // Test `keyword_autocomplete` method:
+
     println!("Autocomplete keyword: {:#?}", search_index.keyword_autocomplete(&"hel".to_string()));
     assert_eq!(search_index.keyword_autocomplete(&"hel".to_string()), vec!["helicopter", "hell", "hello", "help"]);
 
@@ -71,6 +80,11 @@ fn simple() {
     println!("Search keyword: {:#?}", search_index.keyword_search(&"AsSisTanCe".to_string()));
     assert_eq!(search_index.keyword_search(&"AsSisTanCe".to_string()), vec![&3]);
 
+    // Test `keyword_search` method:
+
+    println!("Search keyword: {:#?}", search_index.keyword_search(&"The Bird's the Word".to_string()));
+    assert_eq!(search_index.keyword_search(&"The Bird's the Word".to_string()), vec![&4]);
+
     // Test `search` method:
 
     println!("Search string: {:#?}", search_index.search(&"Helicopter around".to_string()));
